<?php

/**
 * mr-gutter-ltd functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package mr-gutter-ltd
 */

if (! defined('_S_VERSION')) {
	// Replace the version number of the theme on each release.
	define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function mr_gutter_ltd_setup()
{
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on mr-gutter-ltd, use a find and replace
		* to change 'mr-gutter-ltd' to the name of your theme in all the template files.
		*/
	load_theme_textdomain('mr-gutter-ltd', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support('title-tag');

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'header-menu' => esc_html__('Primary', 'mr-gutter-ltd'),
			'footer-menu' => esc_html__('Footer menu', 'mr-gutter-ltd'),
			'policies-menu' => esc_html__('Policies menu', 'mr-gutter-ltd'),
			'seo-menu' => esc_html__('SEO menu', 'mr-gutter-ltd'),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'mr_gutter_ltd_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action('after_setup_theme', 'mr_gutter_ltd_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function mr_gutter_ltd_content_width()
{
	$GLOBALS['content_width'] = apply_filters('mr_gutter_ltd_content_width', 640);
}
add_action('after_setup_theme', 'mr_gutter_ltd_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function mr_gutter_ltd_widgets_init()
{
	register_sidebar(
		array(
			'name'          => esc_html__('Sidebar', 'mr-gutter-ltd'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('Add widgets here.', 'mr-gutter-ltd'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action('widgets_init', 'mr_gutter_ltd_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function mr_gutter_ltd_scripts()
{
	wp_enqueue_style('mr-gutter-ltd-layout-min-css', get_template_directory_uri() . '/assets/css/layout.min.css', array(), '20151215');
	wp_enqueue_style('mr-gutter-ltd-jquery-fancybox-min-css', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');

	wp_enqueue_style('mr-gutter-ltd-style', get_stylesheet_uri(), array(), _S_VERSION);
	wp_enqueue_script('jquery');
	wp_style_add_data('mr-gutter-ltd-style', 'rtl', 'replace');

	wp_enqueue_script('mr-gutter-ltd-layout-js', get_template_directory_uri() . '/assets/js/layout.js', array(), '20151215', true);
	wp_enqueue_script('mr-gutter-ltd-slick-min-js', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('mr-gutter-ltd-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('mr-gutter-ltd-jquery-fancybox-min-js', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_enqueue_script('mr-gutter-ltd-Custome-js', get_template_directory_uri() . '/assets/js/custom.js', array(), '20151215', true);
	wp_localize_script('mr-gutter-ltd-Custome-js', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php'), 'homeurl' => home_url()]);

	wp_enqueue_script('mr-gutter-ltd-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'mr_gutter_ltd_scripts');


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}

// Filter the output of logo to fix Googles Error about itemprop logo
add_filter( 'get_custom_logo', 'change_html_custom_logo' );
function change_html_custom_logo() {
    $custom_logo_id = get_theme_mod( 'custom_logo' );
	$site_name = get_bloginfo( 'name' );
    $html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" title="'.$site_name.'" itemprop="url">%2$s</a>',
            esc_url( home_url( '/' ) ),
            wp_get_attachment_image( $custom_logo_id, 'full', false, array(
                'class'    => 'custom-logo',
				"data-no-lazy" => "1",
				'alt'	=> $site_name." Logo"
            ) )
        );
    return $html;   
}

//W3 Validator issue Fix Code
function remove_auto_sizes_css_fix($add_auto_sizes) {return false;}
add_filter('wp_img_tag_add_auto_sizes', 'remove_auto_sizes_css_fix');


//HOME URL shortcode for the displaying in the Posts pages
add_shortcode( 'display_home_url','homeURLShortcodeCallback'  );
function homeURLShortcodeCallback() {
	return home_url();
}

//Menu Title Attribute Add Code
add_filter('nav_menu_link_attributes', function ($atts, $item, $args, $depth) {
    if (!empty($item->attr_title)) {
        $atts['title'] = $item->attr_title;
    }
    return $atts;
}, 10, 4);

//Content Search, Post file - display structure
function commonBlogStructure(){
	$blog_image = (get_the_post_thumbnail_url()) ? get_the_post_thumbnail_url() : get_field("placeholder_image","option");
	?>
	<div class="blog-item">
		<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="blog-img">
			<div class="back-img"
				style="background-image: url('<?php echo esc_url($blog_image); ?>');">
			</div>
		</a>
		<div class="blog-content">
			<h5 class="blog-title">
				<a href="<?php the_permalink(); ?>"
					title="<?php the_title_attribute(); ?>"><?php the_title(); ?>
				</a>
			</h5>
			<?php the_excerpt(); ?>
		</div>
	</div>
	<?php
}


// Modify the main search query to only search posts
function search_only_posts($query)
{
	// Check if the query is the main query and if it's a search query
	if ($query->is_main_query() && $query->is_search()) {
		// Set the post type to 'post'
		$query->set('post_type', 'post');
	}
}
add_action('pre_get_posts', 'search_only_posts');



//Blog Loadmore
add_action('wp_ajax_loadmore_content', 'posts_loadmore');
add_action('wp_ajax_nopriv_loadmore_content', 'posts_loadmore');

function posts_loadmore()
{

	$page = $_POST['page'];
	// $total_pages = $_POST['total_pages'];
	$posts_show = $_POST['posts_show'];

	$args = array(
		"post_type"     => "post",
		"post_status"   => "publish",
		"posts_per_page" => $posts_show,
		"paged"         => $page
	);
	$blog_posts_query = new WP_Query($args);
	if ($blog_posts_query->have_posts()) {
		while ($blog_posts_query->have_posts()) {
			$blog_posts_query->the_post();  
			?>
			<div class="col-lg-4 col-md-6">
				<?php get_template_part('template-parts/content', get_post_type()); ?>
			</div>
		<?php
			wp_reset_postdata();
		}
	}
	wp_die();
}

//Blog Loadmore
add_action('wp_ajax_testm_loadmore_cnt', 'reviews_loadmore');
add_action('wp_ajax_nopriv_testm_loadmore_cnt', 'reviews_loadmore');

function reviews_loadmore()
{

	$page = $_POST['page'];
	$posts_show = $_POST['posts_show'];

	if ($posts_show == -1) {
		// If posts_show is -1, return all testimonials without pagination
		$args = array(
			'post_type'     => 'testimonials',
			'post_status'   => 'publish',
			'posts_per_page' => -1,  // Get all posts
		);
	} else {
		// Normal pagination for desktop (e.g., 6 posts per page)
		$args = array(
			'post_type'     => 'testimonials',
			'post_status'   => 'publish',
			'posts_per_page' => $posts_show, // Show 6 or a number you specify
			'paged'         => $page,
		);
	}

	$testm_posts_query = new WP_Query($args);
	if ($testm_posts_query->have_posts()) {
		while ($testm_posts_query->have_posts()) {
			$testm_posts_query->the_post();
			$star_rating        = get_field("add_rating") ? get_field("add_rating") : "";
			$review_rating_per  = ($star_rating) ? $star_rating * 20 : "";
		?>
			<div class="testimonials-box-wp">
				<div class="testimonials-box">
					<?php
					if (!empty($review_rating_per)): ?>
						<div class="review-star">
							<div class="star-rating-wp">
								<div class="star-rating">
									<span class="star-rating__fill" style="width: <?php echo esc_html($review_rating_per); ?>%"></span>
								</div>
							</div>
						</div>
					<?php
					endif;
					if (!empty(get_the_content())): ?>
						<div class="testimonials-text body-lg" data-simplebar="init">
							<?php the_content(); ?>
						</div>
					<?php
					endif;
					if (!empty(get_the_title())): ?>
						<div class="testimonial-author">
							<p><?php the_title(); ?></p>
						</div>
					<?php
					endif;
					?>
				</div>
			</div>
			<?php
			wp_reset_postdata();
		}
	}
	wp_die();
}

function get_expertices()
{
	$imgid = $_POST['imgID'];
	if (have_rows('why_choose', 9)):
		while (have_rows('why_choose', 9)):
			the_row();
			if (get_row_index() == $imgid):
				$key_image = get_sub_field('key_image');
				if (!empty($key_image)):
			?>
					<div class="back-img" img-attr=<?php echo get_row_index(); ?> style="background-image: url('<?php echo esc_url($key_image['url']); ?>');"></div>
<?php
				endif;
			endif;
		endwhile;
	endif;

	wp_die();
}


//About  page tabbing
add_action('wp_ajax_nopriv_get_wc_image', 'get_expertices');
add_action('wp_ajax_get_wc_image', 'get_expertices');
// Social Media Common HTMl content
function social_media_info(){                  
		$fb_url         = get_field('facebook_url', 'option');
		$ig_url         = get_field('instagram_url', 'option');
		$x_url          = get_field('twitter_x_url', 'option');
		$linkedin_url   = get_field('linkedin_url', 'option');
		$yt_url         = get_field('youtube_url', 'option');
?>
	<div class="social-media">
		<ul>
			<?php if($fb_url): ?>
				<li>
					<a href="<?php echo esc_url($fb_url['url']); ?>" title="<?php echo esc_attr($fb_url['title']); ?>" target="<?php echo esc_attr($fb_url['target']); ?>">
						<span class="mask-img" style="-webkit-mask-image: url('<?php echo home_url(); ?>/wp-content/uploads/2025/01/facebook.svg');"></span>
					</a>
				</li>
			<?php endif; if($ig_url): ?>
				<li>
					<a href="<?php echo esc_url($ig_url['url']); ?>" title="<?php echo esc_attr($ig_url['title']); ?>" target="<?php echo esc_attr($ig_url['target']); ?>">
						<span class="mask-img" style="-webkit-mask-image: url('<?php echo home_url(); ?>/wp-content/uploads/2025/01/instagram.svg');"></span>
					</a>
				</li>
			<?php endif; if($x_url): ?>
				<li>
					<a href="<?php echo esc_url($x_url['url']); ?>" title="<?php echo esc_attr($x_url['title']); ?>" target="<?php echo esc_attr($x_url['target']); ?>">
						<span class="mask-img" style="-webkit-mask-image: url('<?php echo home_url(); ?>/wp-content/uploads/2025/01/x.svg');"></span>
					</a>
				</li>
			<?php endif; if($linkedin_url): ?>
				<li>
					<a href="<?php echo esc_url($linkedin_url['url']); ?>" title="<?php echo esc_attr($linkedin_url['title']); ?>" target="<?php echo esc_attr($linkedin_url['target']); ?>">
						<span class="mask-img" style="-webkit-mask-image: url('<?php echo home_url(); ?>/wp-content/uploads/2025/01/linkedIn.svg');"></span>
					</a>
				</li>
			<?php endif; if($yt_url): ?>
				<li>
					<a href="<?php echo esc_url($yt_url['url']); ?>" title="<?php echo esc_attr($yt_url['title']); ?>" target="<?php echo esc_attr($yt_url['target']); ?>">
						<span class="mask-img" style="-webkit-mask-image: url('<?php echo home_url(); ?>/wp-content/uploads/2025/01/youtube.svg');"></span>
					</a>
				</li>
			<?php endif; ?>
		</ul>
	</div>  				
	
<?php
}

// Contact information Common HTML
function contact_info(){
	
	//  Phone Number Veriables..
		$fo_ph_label    = get_field('footer_phone_label','option');
		$pr_ph_label    = get_field('primary_phone_no_label','option');
		$se_ph_label    = get_field('secondary_phone_no_label','option');
		$pr_ph_num      = get_field('pr_phone_number','option');
		$sy_ph_num      = get_field('sy_phone_number','option');
		$ph_prefix      = get_field('primary_phone_number_prefix','option');
	//  Email Veriable..
		$fo_em_label    = get_field('footer_email_label','option');
		$email_id       = get_field('email_id','option');
	// Address Veriable..
		$fo_add_label   = get_field('footer_address_label','option');
		$add_text       = get_field('address_text','option');
		$add_url        = get_field('address_url','option');
	if(!empty($pr_ph_num) || !empty($sy_ph_num) || !empty($email_id) || !empty($add_text) || !empty($add_url)):
	?>

			<?php if(!empty($pr_ph_num) || !empty($pr_ph_num)) : ?>
				<div class="contact-link-box">
					<?php if(!empty($fo_em_label)) : ?>
						<h4 class="h4-title"><?php esc_html_e($fo_ph_label); ?></h4>
					<?php endif; ?>
					<?php if(!empty($pr_ph_num) || !empty($sy_ph_num)) : ?>
						<div class="contact-link-text">
							<?php if(!empty($pr_ph_num)) : ?><p><?php esc_html_e($pr_ph_label); ?> <a href="<?php echo esc_url($pr_ph_num['url']);?>" title="<?php echo esc_attr(ucfirst($ph_prefix) ." ". $pr_ph_num['title']);?>"><span class="callus"><?php esc_html_e($pr_ph_num['title']);?></span></a></p><?php endif; ?>
							<?php if(!empty($sy_ph_num)) : ?><p><?php esc_html_e($se_ph_label); ?> <a href="<?php echo esc_url($sy_ph_num['url']);?>" title="<?php echo esc_attr(ucfirst($ph_prefix) ." ". $sy_ph_num['title']);?>"><span class="callus"><?php esc_html_e($sy_ph_num['title']);?></span></a></p><?php endif; ?>
						</div>
					<?php endif; ?>
				</div>
			<?php endif;   ?>
			<?php if(!empty($fo_em_label) || !empty($email_id)) : ?>
				<div class="contact-link-box">
					<?php if(!empty($fo_em_label)) : ?>
					<h4 class="h4-title"><?php esc_html_e($fo_em_label); ?></h4>
					<?php endif;?>
					<?php if(!empty($email_id)) : ?>
						<div class="contact-link-text">
							<a href="mailto:<?php echo esc_attr($email_id); ?>" title="<?php echo esc_attr($email_id); ?>"><?php echo esc_attr($email_id); ?></a>
						</div>
					<?php endif;?>
				</div>
			<?php endif; 
			if(!empty($fo_add_label) || !empty($add_url) ): ?>
				<div class="contact-link-box address-link-box">
					<?php if(!empty($fo_add_label)) :?> 
					<h4 class="h4-title"><?php esc_html_e($fo_add_label); ?></h4>
					<?php  endif; 
						if(!empty($add_url)): ?>
						<div class="contact-link-text">
							<a href="<?php echo esc_url($add_url); ?>" target="_blank" title="<?php echo strip_tags($add_text); ?>"><?php echo wp_kses($add_text, array('span' => array())); ?></a>
						</div>
					<?php endif;?>
				</div>
			<?php endif;?>
		
	<?php endif;
}

function load_more_gallery_images() {
    $g_page = isset($_POST['g_page']) ? intval($_POST['g_page']) : 1;
    $g_posts_show = isset($_POST['per_page']) ? intval($_POST['per_page']) : 9;
	$offset = ($g_page - 1) * $g_posts_show;

	$front_pageID = get_option('page_on_front');
	$home_gallery  = get_field("home_gallery", $front_pageID);

    if ($home_gallery) {
	
		$home_gallery_imgs = (!empty($home_gallery['home_gallery_images'])) ? $home_gallery['home_gallery_images'] : [];

        $total_images = count($home_gallery_imgs);
		$remaining = $total_images - ($offset + $g_posts_show);

        $output = '';
		$visible_images = array_slice($home_gallery_imgs, $offset, $g_posts_show);

		$g_index = $offset + 1; // Maintain correct indexing
		foreach ($visible_images as $image) {
			$output .= '<div class="col-lg-4 col-6">
                            <div class="gallery-image">
                                <a href="'.esc_url($image).'" title="'.esc_html("Gallery Image ".$g_index).'" data-fancybox="gallery-images">
                                    <div class="back-img" style="background-image: url('.esc_url($image).');"></div>
                                </a>
                            </div>
                        </div>';
			$g_index++;
		}

        wp_send_json([
            'html' => $output,
			'has_more' => ($remaining > 0)
        ]);
    } else {
        wp_send_json(['html' => '', 'has_more' => false]);
    }

    wp_die();
}
add_action('wp_ajax_load_more_gallery', 'load_more_gallery_images');
add_action('wp_ajax_nopriv_load_more_gallery', 'load_more_gallery_images');